@@ -821,7 +821,7 @@ plot.difNLR <- function(x, plot.type = "cc", item = "all",
                       ### theme
                       ggtitle(TITLE) +
                       labs(x = "Standardized total score", y = "Probability of correct answer") +
-                      scale_y_continuous(expand = c(0, 0), limits = c(0, 1)) +
+                      scale_y_continuous(limits = c(0, 1)) +
                       theme_bw() +
                       theme(text = element_text(size = 11),
                             plot.title = element_text(size = 11, face = "bold", vjust = 1.5),
